package org.jboss.tutorial.entity.bean;

import java.util.Collection;

import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

@Stateless
@Remote(CustomerManager.class)
public class CustomerManagerBean 
  implements CustomerManager 
{
  @PersistenceContext(unitName="lab-entity-demo4")  // maps to persistence.xml
  private EntityManager manager;
  
  public void createCustomer(Customer c) 
  {
    System.out.println("[CustomerManagerBean] createCustomer("+c+")");
    
    manager.persist(c);
    manager.flush();
  }
  
  public Customer findCustomer(int id) 
  {
    System.out.println("[CustomerManagerBean] findCustomer("+id+")");  
    
    return manager.find(Customer.class,id);
  }
  
  public Collection<Customer> findCustomerByName(String nameToBeFound) 
  {   	  
    System.out.println("[CustomerManagerBean] findCustomerByName("+nameToBeFound+")");
    
    Query query = manager.createQuery("SELECT c from Customer c where UPPER(c.lastName) like :soughtAfterName");
    query.setParameter("soughtAfterName",nameToBeFound);
   
    return (Collection<Customer>) query.getResultList();
  }
   
  public void removeCustomer(int id) 
  {
    System.out.println("[CustomerManagerBean] removeCustomer("+id+")");      
    
    Customer toBeRemovedCustomer = findCustomer(id);
    this.removeCustomer(toBeRemovedCustomer);
  }
  
  private void removeCustomer(Customer c) 
  {
    System.out.println("[CustomerManagerBean] removeCustomer("+c+")");      
    
    manager.remove(c);
    manager.flush();
  }
  
  public Collection<Customer> findAllCustomers() 
  {
    System.out.println("[CustomerManagerBean] findAllCustomers()");  
    
    Query query = manager.createQuery("SELECT c FROM Customer c");
    return (Collection<Customer>) query.getResultList();
  }
}

